@@ -14,6 +14,7 @@ from qpd.specs import (
 )
 from qpd_test.tests_base import TestsBase
 from qpd_test.utils import assert_df_eq
+from pytest import raises
 
 
 class QPDEngineTests(object):
@@ -24,6 +25,26 @@ class QPDEngineTests(object):
         def to_native_df(self, data: Any, columns: Any) -> Any:  # pragma: no cover
             raise NotImplementedError
 
+        def test_parse_join_types(self):
+            assert "cross" == self.op.pl_utils.parse_join_type("CROss")
+            assert "inner" == self.op.pl_utils.parse_join_type("join")
+            assert "inner" == self.op.pl_utils.parse_join_type("Inner")
+            assert "left_outer" == self.op.pl_utils.parse_join_type("left")
+            assert "left_outer" == self.op.pl_utils.parse_join_type("left  outer")
+            assert "right_outer" == self.op.pl_utils.parse_join_type("right")
+            assert "right_outer" == self.op.pl_utils.parse_join_type("right_ outer")
+            assert "full_outer" == self.op.pl_utils.parse_join_type("full")
+            assert "full_outer" == self.op.pl_utils.parse_join_type(" outer ")
+            assert "full_outer" == self.op.pl_utils.parse_join_type("full_outer")
+            assert "left_anti" == self.op.pl_utils.parse_join_type("anti")
+            assert "left_anti" == self.op.pl_utils.parse_join_type("left anti")
+            assert "left_semi" == self.op.pl_utils.parse_join_type("semi")
+            assert "left_semi" == self.op.pl_utils.parse_join_type("left semi")
+            raises(
+                NotImplementedError,
+                lambda: self.op.pl_utils.parse_join_type("right semi"),
+            )
+
         def test_comparison_op(self):
             def assert_eq(df, first, second, op, expected):
                 if isinstance(first, str):
